@@ -30,17 +30,17 @@
 #include <time.h>
 
 #include "../core/weechat.h"
-#include "../core/wee-config.h"
-#include "../core/wee-crypto.h"
-#include "../core/wee-hashtable.h"
-#include "../core/wee-hook.h"
-#include "../core/wee-infolist.h"
-#include "../core/wee-proxy.h"
-#include "../core/wee-secure.h"
-#include "../core/wee-string.h"
-#include "../core/wee-url.h"
-#include "../core/wee-util.h"
-#include "../core/wee-version.h"
+#include "../core/core-config.h"
+#include "../core/core-crypto.h"
+#include "../core/core-hashtable.h"
+#include "../core/core-hook.h"
+#include "../core/core-infolist.h"
+#include "../core/core-proxy.h"
+#include "../core/core-secure.h"
+#include "../core/core-string.h"
+#include "../core/core-url.h"
+#include "../core/core-util.h"
+#include "../core/core-version.h"
 #include "../gui/gui-bar.h"
 #include "../gui/gui-bar-item.h"
 #include "../gui/gui-bar-window.h"
@@ -239,6 +239,24 @@ plugin_api_info_weechat_data_dir_cb (const void *pointer, void *data,
     return plugin_api_info_absolute_path (weechat_data_dir);
 }
 
+/*
+ * Returns WeeChat info "weechat_state_dir".
+ */
+
+char *
+plugin_api_info_weechat_state_dir_cb (const void *pointer, void *data,
+                                      const char *info_name,
+                                      const char *arguments)
+{
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) info_name;
+    (void) arguments;
+
+    return plugin_api_info_absolute_path (weechat_state_dir);
+}
+
 /*
  * Returns WeeChat info "weechat_cache_dir".
  */
@@ -840,8 +858,7 @@ plugin_api_info_nick_color_cb (const void *pointer, void *data,
         -1,
         (num_items >= 2) ? items[1] : NULL);
 
-    if (items)
-        string_free_split (items);
+    string_free_split (items);
 
     return result;
 }
@@ -870,8 +887,7 @@ plugin_api_info_nick_color_name_cb (const void *pointer, void *data,
         -1,
         (num_items >= 2) ? items[1] : NULL);
 
-    if (items)
-        string_free_split (items);
+    string_free_split (items);
 
     return result;
 }
@@ -910,8 +926,7 @@ plugin_api_info_nick_color_ignore_case_cb (const void *pointer, void *data,
         case_range,
         (num_items >= 3) ? items[2] : NULL);
 
-    if (items)
-        string_free_split (items);
+    string_free_split (items);
 
     return result;
 }
@@ -950,8 +965,7 @@ plugin_api_info_nick_color_name_ignore_case_cb (const void *pointer, void *data,
         case_range,
         (num_items >= 3) ? items[2] : NULL);
 
-    if (items)
-        string_free_split (items);
+    string_free_split (items);
 
     return result;
 }
@@ -1101,10 +1115,8 @@ plugin_api_info_totp_generate_cb (const void *pointer, void *data,
     return totp;
 
 error:
-    if (argv)
-        string_free_split (argv);
-    if (totp)
-        free (totp);
+    string_free_split (argv);
+    free (totp);
     return NULL;
 }
 
@@ -1174,8 +1186,40 @@ plugin_api_info_totp_validate_cb (const void *pointer, void *data,
     return strdup (value);
 
 error:
-    if (argv)
-        string_free_split (argv);
+    string_free_split (argv);
+    return NULL;
+}
+
+/*
+ * Returns WeeChat info "plugin_loaded".
+ */
+
+char *
+plugin_api_info_plugin_loaded_cb (const void *pointer, void *data,
+                                  const char *info_name,
+                                  const char *arguments)
+{
+    struct t_weechat_plugin *ptr_plugin;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) info_name;
+
+    if (!arguments || !arguments[0])
+        return NULL;
+
+    for (ptr_plugin = weechat_plugins; ptr_plugin;
+         ptr_plugin = ptr_plugin->next_plugin)
+    {
+        if (strcmp (ptr_plugin->name, arguments) == 0)
+        {
+            /* plugin loaded */
+            return strdup ("1");
+        }
+    }
+
+    /* plugin not loaded */
     return NULL;
 }
 
@@ -2076,7 +2120,8 @@ plugin_api_info_init ()
                N_("WeeChat directory "
                   "(*deprecated* since version 3.2, replaced by "
                   "\"weechat_config_dir\", \"weechat_data_dir\", "
-                  "\"weechat_cache_dir\" and \"weechat_runtime_dir\")"),
+                  "\"weechat_state_dir\" , \"weechat_cache_dir\" "
+                  "and \"weechat_runtime_dir\")"),
                NULL, &plugin_api_info_weechat_data_dir_cb, NULL, NULL);
     hook_info (NULL, "weechat_config_dir",
                N_("WeeChat config directory"),
@@ -2084,6 +2129,9 @@ plugin_api_info_init ()
     hook_info (NULL, "weechat_data_dir",
                N_("WeeChat data directory"),
                NULL, &plugin_api_info_weechat_data_dir_cb, NULL, NULL);
+    hook_info (NULL, "weechat_state_dir",
+               N_("WeeChat state directory"),
+               NULL, &plugin_api_info_weechat_state_dir_cb, NULL, NULL);
     hook_info (NULL, "weechat_cache_dir",
                N_("WeeChat cache directory"),
                NULL, &plugin_api_info_weechat_cache_dir_cb, NULL, NULL);
@@ -2234,6 +2282,10 @@ plugin_api_info_init ()
                   "timestamp (optional, current time by default), number of "
                   "passwords before/after to test (optional, 0 by default)"),
                &plugin_api_info_totp_validate_cb, NULL, NULL);
+    hook_info (NULL, "plugin_loaded",
+               N_("1 if plugin is loaded"),
+               N_("plugin name"),
+               &plugin_api_info_plugin_loaded_cb, NULL, NULL);
 
     /* WeeChat core info_hashtable hooks */
     hook_info_hashtable (NULL,
